API
===

.. currentmodule:: particle_tracking_manager

Main Modules
------------

.. autosummary::
   :toctree: generated/
   :recursive:

   the_manager
   models.opendrift.opendrift

Configuration Classes
---------------------

.. autosummary::
   :toctree: generated/
   :recursive:

   config_the_manager
   models.opendrift.config_opendrift
   ocean_model_registry
   config_ocean_model
   config_logging
   config_misc
